==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/content/messages/bg/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Вижда се и за нечленове на това пространство)',
    '<strong>Confirm</strong> post deletion' => '<strong>Потвърждение</strong> след изтриване',
    '<strong>Move</strong> content' => '<strong>Преместване</strong> на съдържание',
    '<strong>Permalink</strong> to this post' => '<strong>Постоянна връзка</strong> към тази публикация',
    'Activated' => 'Активиран',
    'Add a member to notify' => 'Добавете член, който да уведомите',
    'Archived' => 'Архивирано',
    'Attach Files' => 'Прикачи файлове',
    'Back to stream' => 'Обратно към потока',
    'Cancel' => 'Отказ',
    'Cancel Edit' => 'Отказ от Редакция',
    'Change to "Private"' => 'Направи личен',
    'Change to "Public"' => 'Направи публичен',
    'Configure' => 'Настройване',
    'Confirm' => 'Потвърждение',
    'Content' => 'Съдържание',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Маркер на съдържанието с присвоен невалиден контент container_id.',
    'Content has been moved to {spacename}' => 'Съдържанието е преместено в {spacename}',
    'Could not find requested content!' => 'Не може да бъде намерено исканото съдържание!',
    'Created by me' => 'Създадени от мен',
    'Creation time' => 'Време на създаване',
    'Delete' => 'Изтрий',
    'Deleted' => 'Изтрита',
    'Do you really want to delete this post? All likes and comments will be lost!' => 'Наистина ли искате да изтриете тази публикация? Всички харесвания и коментари ще бъдат загубени!',
    'Edit' => 'Редакция',
    'Enable' => 'Активиране',
    'Filter' => 'Филтър',
    'I\'m involved' => 'Където съм участник',
    'Invalid content id given!' => 'Даден е невалиден идентификатор на съдържанието!',
    'Invalid request method!' => 'Невалиден метод на заявка!',
    'Invalid space selection.' => 'Невалиден избор на раздел.',
    'Last update' => 'Последна промяна',
    'Last updated {time}' => 'Последно променен {time}',
    'Load more' => 'Зареди повече',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Достигнат е максимален брой фиксирани елементи!<br>Можете да фиксирате само до {count} елемента наведнъж.',
    'Move content' => 'Премести съдържание',
    'Move to archive' => 'Преместване в архив',
    'No matches with your selected filters!' => 'Няма съвпадения с избраните филтри!',
    'None' => 'Никакъв',
    'Nothing here yet!' => 'Все още няма нищо тук!',
    'Notify members' => 'Уведоми членовете',
    'Permalink' => 'Постоянна връзка',
    'Pin to top' => 'Закачете го отгоре',
    'Pinned' => 'Закачено',
    'Private' => 'Личен',
    'Public' => 'Публично',
    'Specify who can see this content.' => 'Посочете кой може да вижда това съдържание.',
    'Submit' => 'Изпращане',
    'Tag' => 'Етикет',
    'Target Space' => 'Целеви раздел',
    'The author of this content is not allowed to create private content within the selected space.' => 'Авторът на това съдържание няма право да създава лично съдържание в избраният раздел.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Авторът на това съдържание няма право да създава публично съдържание в избраният раздел.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Авторът на това съдържание няма право да създава този тип съдържание в този раздел.',
    'The content can\'t be moved to its current space.' => 'Съдържанието не може да бъде преместено в текущият му раздел.',
    'The content has been archived.' => 'Съдържанието е архивирано.',
    'The content has been deleted.' => 'Съдържанието е изтрито.',
    'The content has been unarchived.' => 'Съдържанието е деархивирано.',
    'The given name is already in use.' => 'Даденото име вече се използва.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Модулът {moduleName} не е активиран в избраният целеви раздел.',
    'This action is disabled!' => 'Това действие е деактивирано!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Този тип съдържание не може да бъде преместен поради липсваща настройка за идентификация на модул.',
    'This content type can\'t be moved.' => 'Този тип съдържание не може да бъде преместено.',
    'This space is archived.' => 'Този раздел е архивиран.',
    'This space is not visible!' => 'Този раздел не се вижда!',
    'Topics' => 'Теми',
    'Turn off notifications' => 'Изключи известията',
    'Turn on notifications' => 'Включи известията',
    'Unarchive' => 'Разархивиране',
    'Unpin' => 'Освободи',
    'Updated' => 'Актуализирано',
    'Visible also to unregistered users' => 'Видим и за нерегистрирани потребители',
    'Visible only to you' => 'Видимо само за вас',
    'Visible to all Space members' => 'Видимо за всички членове на Раздела',
    'Visible to all signed in users' => 'Видимо за всички влезли потребители',
    'Visible to friends of {displayName}' => 'Вижда се от приятели на {displayName}',
    'Visible to you and {displayName}' => 'Вижда се от вас и {displayName}',
    'Visible to your friends' => 'Видимо за вашите приятели',
    'With attachments' => 'С прикачени файлове',
    'You do not have the permission to move this content to the given space.' => 'Нямате разрешение да преместите това съдържание в даденият раздел.',
    'You do not have the permission to move this content.' => 'Нямате разрешение да преместите това съдържание.',
    'Your last edit state has been saved!' => 'Последното състояние на редактиране е запазено!',
    'in' => 'в',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Add tag...' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Draft' => '',
    'Hidden' => '',
    'Lock comments' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Schedule publication' => '',
    'Scheduled at {dateTime}' => '',
    'Select type...' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/bg/base.php <==
<?php

return [
    '(Also visible to non-members of this space)' => '(Вижда се и за нечленове на това пространство)',
    '<strong>Move</strong> content' => '<strong>Преместване</strong> на съдържание',
    '<strong>Permalink</strong> to this post' => '<strong>Постоянна връзка</strong> към тази публикация',
    'Activated' => 'Активиран',
    'Add a member to notify' => 'Добавете член, който да уведомите',
    'Archived' => 'Архивирано',
    'Attach Files' => 'Прикачи файлове',
    'Back to stream' => 'Обратно към потока',
    'Cancel' => 'Отказ',
    'Cancel Edit' => 'Отказ от Редакция',
    'Change to "Private"' => 'Направи личен',
    'Change to "Public"' => 'Направи публичен',
    'Configure' => 'Настройване',
    'Confirm' => 'Потвърждение',
    'Content' => 'Съдържание',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Маркер на съдържанието с присвоен невалиден контент container_id.',
    'Content has been moved to {spacename}' => 'Съдържанието е преместено в {spacename}',
    'Could not find requested content!' => 'Не може да бъде намерено исканото съдържание!',
    'Created by me' => 'Създадени от мен',
    'Creation time' => 'Време на създаване',
    'Delete' => 'Изтрий',
    'Deleted' => 'Изтрита',
    'Edit' => 'Редакция',
    'Enable' => 'Активиране',
    'Filter' => 'Филтър',
    'I\'m involved' => 'Където съм участник',
    'Invalid content id given!' => 'Даден е невалиден идентификатор на съдържанието!',
    'Invalid request method!' => 'Невалиден метод на заявка!',
    'Invalid space selection.' => 'Невалиден избор на раздел.',
    'Last update' => 'Последна промяна',
    'Last updated {time}' => 'Последно променен {time}',
    'Load more' => 'Зареди повече',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'Достигнат е максимален брой фиксирани елементи!<br>Можете да фиксирате само до {count} елемента наведнъж.',
    'Move content' => 'Премести съдържание',
    'Move to archive' => 'Преместване в архив',
    'No matches with your selected filters!' => 'Няма съвпадения с избраните филтри!',
    'None' => 'Никакъв',
    'Nothing here yet!' => 'Все още няма нищо тук!',
    'Notify members' => 'Уведоми членовете',
    'Permalink' => 'Постоянна връзка',
    'Pin to top' => 'Закачете го отгоре',
    'Pinned' => 'Закачено',
    'Private' => 'Личен',
    'Public' => 'Публично',
    'Specify who can see this content.' => 'Посочете кой може да вижда това съдържание.',
    'Submit' => 'Изпращане',
    'Tag' => 'Етикет',
    'Target Space' => 'Целеви раздел',
    'The author of this content is not allowed to create private content within the selected space.' => 'Авторът на това съдържание няма право да създава лично съдържание в избраният раздел.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Авторът на това съдържание няма право да създава публично съдържание в избраният раздел.',
    'The author of this content is not allowed to create this type of content within this space.' => 'Авторът на това съдържание няма право да създава този тип съдържание в този раздел.',
    'The content can\'t be moved to its current space.' => 'Съдържанието не може да бъде преместено в текущият му раздел.',
    'The content has been archived.' => 'Съдържанието е архивирано.',
    'The content has been deleted.' => 'Съдържанието е изтрито.',
    'The content has been unarchived.' => 'Съдържанието е деархивирано.',
    'The given name is already in use.' => 'Даденото име вече се използва.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Модулът {moduleName} не е активиран в избраният целеви раздел.',
    'This action is disabled!' => 'Това действие е деактивирано!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Този тип съдържание не може да бъде преместен поради липсваща настройка за идентификация на модул.',
    'This content type can\'t be moved.' => 'Този тип съдържание не може да бъде преместено.',
    'This space is archived.' => 'Този раздел е архивиран.',
    'This space is not visible!' => 'Този раздел не се вижда!',
    'Topics' => 'Теми',
    'Turn off notifications' => 'Изключи известията',
    'Turn on notifications' => 'Включи известията',
    'Unarchive' => 'Разархивиране',
    'Unpin' => 'Освободи',
    'Updated' => 'Актуализирано',
    'Visible also to unregistered users' => 'Видим и за нерегистрирани потребители',
    'Visible only to you' => 'Видимо само за вас',
    'Visible to all Space members' => 'Видимо за всички членове на Раздела',
    'Visible to all signed in users' => 'Видимо за всички влезли потребители',
    'Visible to friends of {displayName}' => 'Вижда се от приятели на {displayName}',
    'Visible to you and {displayName}' => 'Вижда се от вас и {displayName}',
    'Visible to your friends' => 'Видимо за вашите приятели',
    'With attachments' => 'С прикачени файлове',
    'You do not have the permission to move this content to the given space.' => 'Нямате разрешение да преместите това съдържание в даденият раздел.',
    'You do not have the permission to move this content.' => 'Нямате разрешение да преместите това съдържание.',
    'Your last edit state has been saved!' => 'Последното състояние на редактиране е запазено!',
    'in' => 'в',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Add tag...' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Hidden' => '',
    'Lock comments' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'Select type...' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];
